==> react-ui-library-2.0.0.tgz: package/src/stories/sub-navigation-bar-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Text,
  Content,
  SubNavigationBar,
  SubNavigationBarLink,
  theme
} from '../components'
const { minorScale, majorScale } = theme

export default function subNavigationBarStory (module) {
  storiesOf('Sub Navigation Bar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
{`
# Sub Navigation Bar

The SubNavigationBar component. Implements \`<Pane />\`.

\`\`\`
<SubNavigationBar left={'Sources'}>
  {['Overview', 'Integrations', 'Debugger', 'Schema', 'Settings'].map(name =>
    <SubNavigationBarLink key={name} href='#' active={name === 'Overview'}>
      {name}
    </SubNavigationBarLink>
  )}
</SubNavigationBar>
\`\`\`

`}
          </Content>
          <SubNavigationBar left={'Sources'}>
            {['Overview', 'Integrations', 'Debugger', 'Schema', 'Settings'].map(name =>
              <SubNavigationBarLink key={name} href='#' active={name === 'Overview'}>
                {name}
              </SubNavigationBarLink>
            )}
          </SubNavigationBar>
          <Content markdown marginTop={majorScale(2)}>
{`
prop | type | default | description
-----|------| --------|-------------
\`children\` | node | undefined | optional component in center
\`left\` | node/string | undefined | if string wrapped in \`<SubNavigationBarTitle />\`
\`right\` | node | undefined | optional component in right corner
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <SubNavigationBar left={'Sources'}>
        {['Overview', 'Integrations', 'Debugger', 'Schema', 'Settings'].map(name =>
          <SubNavigationBarLink key={name} href='#' active={name === 'Overview'}>
            {name}
          </SubNavigationBarLink>
        )}
      </SubNavigationBar>
    ))
}

==> react-ui-library-2.4.2.tgz: package/src/stories/sub-navigation-bar-story.js <==
import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  SubNavigationBar,
  SubNavigationBarLink,
  theme
} from '../components'
const { majorScale } = theme

export default function subNavigationBarStory (module) {
  storiesOf('Sub Navigation Bar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Sub Navigation Bar

The SubNavigationBar component. Implements \`<Pane />\`.

\`\`\`
<SubNavigationBar left={'Sources'}>
  {['Overview', 'Integrations', 'Debugger', 'Schema', 'Settings'].map(name =>
    <SubNavigationBarLink key={name} href='#' active={name === 'Overview'}>
      {name}
    </SubNavigationBarLink>
  )}
</SubNavigationBar>
\`\`\`

`}
          </Content>
          <SubNavigationBar left={'Sources'}>
            {['Overview', 'Integrations', 'Debugger', 'Schema', 'Settings'].map(name =>
              <SubNavigationBarLink key={name} href='#' active={name === 'Overview'}>
                {name}
              </SubNavigationBarLink>
            )}
          </SubNavigationBar>
          <Content markdown marginTop={majorScale(2)}>
            {`
prop | type | default | description
-----|------| --------|-------------
\`children\` | node | undefined | optional component in center
\`left\` | node/string | undefined | if string wrapped in \`<SubNavigationBarTitle />\`
\`right\` | node | undefined | optional component in right corner
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <SubNavigationBar left={'Sources'}>
        {['Overview', 'Integrations', 'Debugger', 'Schema', 'Settings'].map(name =>
          <SubNavigationBarLink key={name} href='#' active={name === 'Overview'}>
            {name}
          </SubNavigationBarLink>
        )}
      </SubNavigationBar>
    ))
}
